@@ -1,4 +1,4 @@
-from .src/progb/main import Bar
+from .src.progb.main import Bar
 
-__version__ = "0.0.5"
+__version__ = "0.0.6"
 __author__ = {"Henry Cook":"henryscookolaizola@gmail.com"}
\ No newline at end of file
